package provide app-launch 1.0
package require Tk
# launch.tcl --
#     Launch the various exercise programs
#
set srcdir [file dirname [info script]]

# setupMainWindow --
#     Set up the main window - a columns of buttons
#
# Arguments:
#     None
#
# Side effects:
#     The main window is filled
#
proc setupMainWindow {} {
    global srcdir

    set iconfile [file join $srcdir "enter_logo.ico"]
    #wm iconbitmap . $iconfile

    canvas .clogo -bg white -width 500 -height 300
    image create photo logo -file [file join $srcdir enter_logo_small.png]
    .clogo create image 250  20 -image logo -anchor n
    .clogo create text  250 200 -text \
"Workshop Nanoparticles
Luxembourg, march 2015" -anchor n -font "Helvetica 16 bold" -justify c

    ::ttk::labelframe .frame -text "Run exercises"
    ::ttk::button .frame.bpfma    -text Run -command {run pfma}
    ::ttk::label  .frame.lpfma    -text "Probabilistic Material Flow Analysis"
    ::ttk::button .frame.bcolumn  -text Run -command {run column}
    ::ttk::label  .frame.lcolumn  -text "Column experiment"
    ::ttk::button .frame.briver   -text Run -command {run river}
    ::ttk::label  .frame.lriver   -text "Transport of nanoparticles in a river"
    ::ttk::button .frame.bmotor   -text Run -command {run motorway}
    ::ttk::label  .frame.lmotor   -text "Nanoparticles in soil near a motorway"
    ::ttk::button .frame.bhandout -text "Show the handout" -command {run handout}
    ::ttk::label  .frame.lhandout -text " "

    ::ttk::label  .frame.help    -text "Press the Run button to\nstart the exercise"

    ::ttk::button .exit          -text Exit -command exit

    grid .frame .clogo -sticky news
    grid .frame.bpfma    .frame.lpfma    -padx 4 -pady 4
    grid .frame.bcolumn  .frame.lcolumn  -padx 4 -pady 4
    grid .frame.briver   .frame.lriver   -padx 4 -pady 4
    grid .frame.bmotor   .frame.lmotor   -padx 4 -pady 4
    grid .frame.lhandout .frame.bhandout -padx 4 -pady 30
    grid .frame.help     -               -padx 4 -pady 30

    grid .exit - -pady 4
}

# run --
#     Run the program that represents the exercise
#
# Arguments:
#     exercise
#
if { $::tcl_platform(platform) == "windows" } {
proc run {exercise} {
    switch -- $exercise {
        "pfma" {
             exec ../bin/exercise_pmfa.exe &
        }
        "column" {
             exec ../bin/exercise_column.exe &
        }
        "river" {
             exec ../bin/exercise_river.exe &
        }
        "motorway" {
             exec c:/windows/system32/cmd.exe /c {..\bin\exercise_motorway.xlsx} &
        }
        "handout" {
             exec c:/windows/system32/cmd.exe /c {..\doc\handout.pdf} &
        }
    }
}
} else {
proc run {exercise} {
    switch -- $exercise {
        "pfma" {
             exec exercise_pmfa &
        }
        "column" {
             exec exercise_column &
        }
        "river" {
             tk_messageBox -type ok -message "Sorry, this one does not work on OS X"
        }
        "motorway" {
             tk_messageBox -type ok -message "Open the file \"exercise_motorway.xlsx\" in MS Excel"
        }
        "handout" {
             tk_messageBox -type ok -message "Open the file \"handout.pdf\" in Adobe Reader"
        }
    }
}
}

# main --
#     Get the program going
#
setupMainWindow

if { $::tcl_platform(platform) == "windows" } {
if { [file exists c:/nano_exercises] } {
    cd c:/nano_exercises/exercises
} else {
    cd d:/nano_exercises/exercises
}
}
